"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildMinutesQuota = void 0;
const node_util_1 = require("node:util");
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const cache_1 = require("@jfrog-pipelines/cache");
const logger_1 = require("@jfrog-pipelines/logger");
const node_uuid_1 = __importDefault(require("node-uuid"));
const utility_1 = require("@jfrog-pipelines/utility");
const errors_1 = require("@jfrog-pipelines/errors");
class BuildMinutesQuota {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('BuildMinutesQuota');
    }
    async process(waitingGroups, processingGroups, incompleteSteplets, client, publisher) {
        let hasExceededBuildMinutes = false;
        try {
            hasExceededBuildMinutes = await this.fetchFreeTierUsage();
        }
        catch {
            hasExceededBuildMinutes = false;
        }
        if (!hasExceededBuildMinutes) {
            return true;
        }
        await this.cancelFurtherRuns(waitingGroups, processingGroups, incompleteSteplets, client, publisher);
        return false;
    }
    async fetchFreeTierUsage() {
        try {
            const rtAdapter = await internal_clients_1.ArtifactoryAdapter.create(12);
            const result = await rtAdapter.getBlockUsages();
            return !!result.buildTimeBlocked;
        }
        catch {
            throw new errors_1.InvalidUserError('User is not free tier');
        }
    }
    async cancelFurtherRuns(waitingGroups, processingGroups, incompleteSteplets, client, publisher) {
        await this.postStepletCancellationMessages(incompleteSteplets, publisher);
        await this.cancelIncompleteRuns(waitingGroups, processingGroups, client);
    }
    async postStepletCancellationMessages(incompleteSteplets, publisher) {
        const incompleteStepletsByPipelineId = Object.entries((0, utility_1.groupBy)(incompleteSteplets, 'pipelineId'));
        const batchSize = 100;
        await (0, utility_1.eachLimit)(incompleteStepletsByPipelineId, batchSize, async (incompleteStepletsForPipelineId) => {
            const pipelineId = Number.parseInt(incompleteStepletsForPipelineId[0], 10);
            const stepletIds = (0, utility_1.map)(incompleteStepletsForPipelineId[1], 'id');
            await this.postStepCancelledConsoles(pipelineId, stepletIds, publisher);
        });
    }
    async postStepCancelledConsoles(pipelineId, stepletIds, publisher) {
        const postMessageToLogWorkerPromises = [];
        stepletIds.map((stepletId) => {
            const message = this.createMessage(stepletId, pipelineId);
            const postMessageToLogWorkerPromise = this.postMessageToLogWorker(stepletId, pipelineId, message, publisher);
            postMessageToLogWorkerPromises.push(postMessageToLogWorkerPromise);
        });
        await Promise.allSettled(postMessageToLogWorkerPromises);
    }
    createMessage(stepletId, pipelineId) {
        const groupConsoleId = node_uuid_1.default.v4();
        const commandConsoleId = node_uuid_1.default.v4();
        const messageConsoleId = node_uuid_1.default.v4();
        const message = {
            payload: {
                action: 'add',
                manifest: {
                    objectId: stepletId,
                    pipelineId: pipelineId,
                    message: [
                        {
                            type: 'grp',
                            consoleId: groupConsoleId,
                            parentConsoleId: 'root',
                            message: 'Cancelling Step'
                        },
                        {
                            type: 'cmd',
                            consoleId: commandConsoleId,
                            parentConsoleId: groupConsoleId,
                            message: 'Info'
                        },
                        {
                            type: 'msg',
                            consoleId: messageConsoleId,
                            parentConsoleId: commandConsoleId,
                            message: 'Cancelling step as build limit has exceeded.'
                        }
                    ]
                }
            }
        };
        return message;
    }
    postMessageToLogWorker(stepletId, pipelineId, message, publisher) {
        try {
            return publisher.publishMessage('core.logService', message);
        }
        catch (error) {
            throw new errors_1.MessagePublishFailedError(`Cannot publish message with stepletId:${stepletId} and pipelineId: ${pipelineId} to core.logService. Error:- ${(0, node_util_1.inspect)(error)}`);
        }
    }
    async cancelIncompleteRuns(waitingGroups, processingGroups, client) {
        const incompleteGroups = [...processingGroups, ...waitingGroups];
        const runIds = [...new Set(incompleteGroups.map((incompleteGroup) => incompleteGroup.runId))];
        const batchSize = 100;
        await (0, utility_1.eachLimit)(runIds, batchSize, async (runId) => {
            try {
                await client.cancelRunByRunId(runId);
            }
            catch (error) {
                this.logger.warn(`Failed to cancel run with runId: ${runId}. Error: ${(0, node_util_1.inspect)(error)}`);
                throw error;
            }
        });
    }
}
__decorate([
    (0, cache_1.cacheable)({ key: 'exceededBuildMinutes' }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], BuildMinutesQuota.prototype, "fetchFreeTierUsage", null);
exports.BuildMinutesQuota = BuildMinutesQuota;
//# sourceMappingURL=BuildMinutesQuota.js.map