"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetStepletsInProgress = void 0;
const node_util_1 = require("node:util");
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
const StepletDao_1 = require("./driven/db/StepletDao");
const StepDao_1 = require("./modules/StepDao");
const CALL_OBJECT_LIMIT = 500;
class GetStepletsInProgress {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('GetStepletsInProgress');
        this.stepletDao = new StepletDao_1.StepletDao();
        this.stepDao = new StepDao_1.StepDao();
    }
    async getConcurrentRunningSteplets() {
        const steps = await this.stepDao.findAll();
        let stepsBatch = [];
        const stepletInProgressPromises = [];
        for (const step of steps) {
            if (stepsBatch.length < CALL_OBJECT_LIMIT) {
                stepsBatch.push(step);
            }
            else {
                const stepletsInProgressPromise = this.getStepletsInProgress(stepsBatch);
                stepletInProgressPromises.push(stepletsInProgressPromise);
                stepsBatch = [];
            }
        }
        stepletInProgressPromises.push(this.getStepletsInProgress(stepsBatch));
        const stepletsInProgress = await Promise.allSettled(stepletInProgressPromises);
        return stepletsInProgress;
    }
    async getStepletsInProgress(stepsBatch) {
        if ((0, utility_1.isEmpty)(stepsBatch)) {
            return [];
        }
        const stepIds = this.getStepIds(stepsBatch) || [];
        if ((0, utility_1.isEmpty)(stepIds)) {
            return [];
        }
        const stepletsInProgress = [];
        try {
            for (const step of stepsBatch) {
                const steplets = (await this.stepletDao.findById(step.id));
                stepletsInProgress.push(steplets);
            }
            return stepletsInProgress;
        }
        catch (error) {
            this.logger.warn("couldn't get steplets because of a database error:", (0, node_util_1.inspect)(error));
            throw new Error("couldn't get steplets");
        }
    }
    getStepIds(stepsBatch) {
        const stepIds = [];
        for (const step of stepsBatch) {
            if (step.configPropertyBag.multiNode) {
                stepIds.push(step.id);
            }
        }
        return stepIds;
    }
}
exports.GetStepletsInProgress = GetStepletsInProgress;
//# sourceMappingURL=GetStepletsInProgress.js.map