"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.License = void 0;
const node_util_1 = require("node:util");
const configuration_1 = require("@jfrog-pipelines/configuration");
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const logger_1 = require("@jfrog-pipelines/logger");
const ConcurrentRunningSteps_1 = require("./ConcurrentRunningSteps");
class License {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('License');
        this.concurrentRunningSteps = new ConcurrentRunningSteps_1.ConcurrentRunningSteps();
    }
    async verify() {
        if (configuration_1.ConfigFactory.config.isSaaS) {
            return;
        }
        await this.callMissionControl();
        const stepletInProgress = (await this.concurrentRunningSteps.process());
        return this.sendResponse(stepletInProgress);
    }
    async callMissionControl() {
        try {
            const mcAdapter = await internal_clients_1.MissionControlAdapter.create(12);
            const pipelinesInfo = await mcAdapter.getPipelinesInfo();
            return pipelinesInfo;
        }
        catch (error) {
            this.logger.warn('Unable to fetch execution node count from Mission Control: ', (0, node_util_1.inspect)(error));
        }
    }
    sendResponse(stepletInProgress) {
        const response = {};
        console.log(stepletInProgress);
        return response;
    }
}
exports.License = License;
//# sourceMappingURL=License.js.map