"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RejectWaitingGroupsByNodePools = void 0;
const utility_1 = require("@jfrog-pipelines/utility");
class RejectWaitingGroupsByNodePools {
    rejectWaitingGroupsByNodePools(availableNodePools, allNodePools, waitingGroups) {
        let availableNodePoolsByName = {};
        let allNodePoolsByName = {};
        const waitingGroupsAfterFiltering = [];
        const waitingForFreeNodePoolCapacity = [];
        availableNodePoolsByName = this.getAvailableNodePoolsByName(availableNodePools);
        allNodePoolsByName = this.getAllNodePoolsByName(allNodePools);
        for (const group of waitingGroups) {
            if (!this.isRejectableGroup(availableNodePoolsByName, allNodePoolsByName, group, waitingForFreeNodePoolCapacity)) {
                waitingGroupsAfterFiltering.push(group);
            }
        }
        return {
            waitingGroupsAfterFiltering: waitingGroupsAfterFiltering,
            waitingForFreeNodePoolCapacity: waitingForFreeNodePoolCapacity
        };
    }
    isRejectableGroup(availableNodePoolsByName, allNodePoolsByName, group, waitingForFreeNodePoolCapacity) {
        if (group.isExternal || !this.approvalValidation(group)) {
            return false;
        }
        const shouldReject = (0, utility_1.isEmpty)(availableNodePoolsByName[group.nodePoolName]);
        if (shouldReject) {
            this.generateReactionContext(allNodePoolsByName, group, waitingForFreeNodePoolCapacity);
        }
        return shouldReject;
    }
    approvalValidation(group) {
        if (group.waitingForFreeNodePoolCapacity) {
            return false;
        }
        if (group.requiresApproval && !group.approvalRequestedAt) {
            return false;
        }
        return true;
    }
    generateReactionContext(allNodePoolsByName, group, waitingForFreeNodePoolCapacity) {
        const nodePool = allNodePoolsByName[group.nodePoolName];
        if (!(0, utility_1.isEmpty)(nodePool)) {
            group.rejectionContext.waitingForFreeNodePoolCapacity = {
                nodePoolName: group.nodePoolName,
                numberOfNodes: nodePool.numberOfNodes,
                timestamp: new Date()
            };
            waitingForFreeNodePoolCapacity.push(group);
        }
    }
    getAllNodePoolsByName(allNodePools) {
        const allNodePoolsByName = {};
        for (const nodePool of allNodePools) {
            allNodePoolsByName[nodePool.name] = nodePool;
        }
        return allNodePoolsByName;
    }
    getAvailableNodePoolsByName(availableNodePools) {
        const availableNodePoolsByName = {};
        for (const nodePool of availableNodePools) {
            availableNodePoolsByName[nodePool.name] = nodePool;
        }
        return availableNodePoolsByName;
    }
}
exports.RejectWaitingGroupsByNodePools = RejectWaitingGroupsByNodePools;
//# sourceMappingURL=RejectWaitingGroupsByNodePools.js.map