"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const ApiNodePoolDataAdapter_1 = require("../ApiNodePoolDataAdapter");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: { config: { apiUrl: 'http://example.com', controlPlaneVersion: '1.23.6', defaultBatchSize: 100 } }
}));
describe('NodePoolDataAdapter test cases', () => {
    const adapter = new ApiNodePoolDataAdapter_1.ApiNodePoolDataAdapter();
    const client = internal_clients_1.PipelinesClient;
    it('should be defined', () => {
        expect(adapter).toBeDefined();
    });
    describe('getNodePools test cases', () => {
        it('should return all the nodePools when empty query is passed', async () => {
            const spy = jest
                .spyOn(client.prototype, 'getNodePools')
                .mockResolvedValueOnce([{ id: 1 }, { id: 2 }]);
            const result = await adapter.getNodePoolsByQuery();
            const mockGetNodePoolsResult = [{ id: 1 }, { id: 2 }];
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith('');
        });
        it('should return the nodePools that are relevant when project source Id is passed', async () => {
            const query = 'projectKeys=100';
            const spy = jest
                .spyOn(client.prototype, 'getNodePools')
                .mockResolvedValueOnce([{ id: 1 }, { id: 2 }]);
            const result = await adapter.getNodePoolsByQuery(query);
            const mockGetNodePoolsResult = [{ id: 1 }, { id: 2 }];
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith(query);
        });
        it('should return the nodePools that are relevant when nodePoolId is passed', async () => {
            const query = 'nodePoolIds=1';
            const spy = jest
                .spyOn(client.prototype, 'getNodePools')
                .mockResolvedValueOnce([{ id: 1 }]);
            const result = await adapter.getNodePoolsByQuery(query);
            const mockGetNodePoolsResult = [{ id: 1 }];
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith(query);
        });
    });
    describe('getNodes test cases', () => {
        it('should return all the nodes when empty query is passed', async () => {
            const spy = jest
                .spyOn(client.prototype, 'getNodes')
                .mockResolvedValueOnce([{ id: 1 }, { id: 2 }]);
            const result = await adapter.getNodesByQuery();
            const mockGetNodePoolsResult = [{ id: 1 }, { id: 2 }];
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith('');
        });
        it('should return all the nodes matching the nodePoolId when passed with a query for the nodePoolId', async () => {
            const query = 'nodePoolIds=100';
            const spy = jest.spyOn(client.prototype, 'getNodes').mockResolvedValueOnce([
                { id: 1, nodePoolId: 100 },
                { id: 2, nodePoolId: 100 }
            ]);
            const result = await adapter.getNodesByQuery(query);
            const mockGetNodePoolsResult = [
                { id: 1, nodePoolId: 100 },
                { id: 2, nodePoolId: 100 }
            ];
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith(query);
        });
    });
    describe('getBuildPlaneMessagesCountByQuery test cases', () => {
        it('should return all the buildPlaneMessagesCount when no query is passed', async () => {
            const spy = jest.spyOn(client.prototype, 'getBuildPlaneMessagesCount').mockResolvedValueOnce(1);
            const result = await adapter.getBuildPlaneMessagesCountByQuery();
            const mockGetNodePoolsResult = 1;
            expect(result).toBeDefined();
            expect(spy).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual(mockGetNodePoolsResult);
            expect(spy).toHaveBeenCalledWith('');
        });
    });
});
//# sourceMappingURL=NodePoolDataAdapter.test.js.map