"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApiSyncDataAdapter_1 = require("../ApiSyncDataAdapter");
const SyncRepository_1 = require("../SyncRepository");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: { config: { apiUrl: 'http://example.com', controlPlaneVersion: '1.23.6', defaultBatchSize: 100 } }
}));
describe('SyncRepository test cases', () => {
    const syncRepository = new SyncRepository_1.SyncRepository();
    const adapterClass = ApiSyncDataAdapter_1.ApiSyncDataAdapter;
    it('should be defined', () => {
        expect(syncRepository).toBeDefined();
    });
    describe('getPipelineSourcesByIdByQuery test cases', () => {
        it('should return pipelineSourceById', async () => {
            const query = '';
            const spy = jest.spyOn(adapterClass.prototype, 'getPipelineSourcesByQuery').mockResolvedValueOnce([
                { id: 1, name: 'source1' },
                { id: 2, name: 'source2' }
            ]);
            const mockExpectedResult = {
                1: { id: 1, name: 'source1' },
                2: { id: 2, name: 'source2' }
            };
            const result = await syncRepository.getPipelineSourcesByIdByQuery(query);
            expect(spy).toHaveBeenCalledTimes(1);
            expect(spy).toHaveBeenCalledWith(query);
            expect(spy).toBeDefined();
            expect(result).toStrictEqual(mockExpectedResult);
        });
        it('should throw error when adapter throws error', async () => {
            const query = '';
            const errorResult = new Error('error');
            const spy = jest.spyOn(adapterClass.prototype, 'getPipelineSourcesByQuery').mockRejectedValueOnce(errorResult);
            expect(spy).toBeDefined();
            await expect(syncRepository.getPipelineSourcesByIdByQuery(query)).rejects.toThrow(errorResult);
            expect(spy).toHaveBeenCalledWith(query);
        });
    });
});
//# sourceMappingURL=SyncRepository.test.js.map