"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepRepository = void 0;
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const DagDao_1 = require("../../driven/db/DagDao");
const StepDao_1 = require("../../driven/db/StepDao");
const StepletDao_1 = require("../../driven/db/StepletDao");
const DagVo_1 = require("./DagVo");
const DagCollectionFilter_1 = require("./DagCollectionFilter");
const StepVo_1 = require("./StepVo");
const StepletVo_1 = require("./StepletVo");
class StepRepository {
    constructor() {
        this.dagDao = new DagDao_1.DagDao();
        this.stepDao = new StepDao_1.StepDao();
        this.stepletDao = new StepletDao_1.StepletDao();
    }
    async getDagRecords() {
        const dagRecords = await this.dagDao.findAll();
        const filteredDagRecords = await DagCollectionFilter_1.DagCollectionFilter.filter(dagRecords);
        const dagVoList = filteredDagRecords.map((record) => {
            return new DagVo_1.DagVo(record);
        });
        return dagVoList;
    }
    async getStepsById(stepIds) {
        const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('id', stepIds).build();
        const steps = await this.stepDao.findAll(query);
        const stepVoList = steps.map((step) => {
            return new StepVo_1.StepVo(step);
        });
        return stepVoList;
    }
    async getStepletsById(stepletIds) {
        const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('id', stepletIds).build();
        const steps = await this.stepletDao.findAll(query);
        const stepVoList = steps.map((steplet) => {
            return new StepletVo_1.StepletVo(steplet);
        });
        return stepVoList;
    }
}
exports.StepRepository = StepRepository;
//# sourceMappingURL=StepRepository.js.map