"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodePoolCollection = void 0;
const NodePoolRepository_1 = require("./NodePoolRepository");
class NodePoolCollection {
    constructor(nodePools) {
        this.nodePools = nodePools;
    }
    getNodePools() {
        return this.nodePools;
    }
    getStaticNodePools() {
        return this.nodePools.filter((nodePool) => nodePool.isStatic());
    }
    getNodePoolsByProjectId() {
        const nodePoolsByProjectId = new Map();
        for (const nodePool of this.nodePools) {
            const projectId = nodePool.getProjectId();
            const nodePools = nodePoolsByProjectId.get(projectId) ?? [];
            nodePools.push(nodePool);
            nodePoolsByProjectId.set(projectId, nodePools);
        }
        return nodePoolsByProjectId;
    }
    async getDefaultNodePoolByProjectId(projectId) {
        const nodePoolRepository = new NodePoolRepository_1.NodePoolRepository();
        const projects = await nodePoolRepository.getProjects();
        let nodePoolId = 0;
        for (const project of projects) {
            if (project.getId() === projectId) {
                nodePoolId = project.getNodePoolId();
            }
        }
        return this.getNodePoolByNodePoolId(nodePoolId);
    }
    getNodePoolByNodePoolId(nodePoolId) {
        for (const nodePool of this.nodePools) {
            if (nodePool.getId() === nodePoolId) {
                return nodePool;
            }
        }
        throw new Error(`No NodePool exist with the given nodePool id: ${nodePoolId}`);
    }
}
exports.NodePoolCollection = NodePoolCollection;
//# sourceMappingURL=NodePoolCollection.js.map