"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepAffinityVo = void 0;
class StepAffinityVo {
    constructor(runIdParameter, affinityGroupParameter, stepsParameter, dagRecords, projectIdParameter, pipelineIdParameter, pipelineSourceIdParameter, nodePoolParameter) {
        this.isJobNodePool = false;
        this.skipByNoNode = false;
        this.skipByNodePoolPermissions = false;
        this.skipByNonRootEnforcement = false;
        this.isStepUsingLocalArtifactory = false;
        this.runId = runIdParameter;
        this.affinityGroup = affinityGroupParameter;
        this.steps = stepsParameter;
        this.requiresApproval = dagRecords.some((record) => [6, 7].includes(record.getDependentEntityType()));
        this.projectId = projectIdParameter;
        this.pipelineId = pipelineIdParameter;
        this.pipelineSourceId = pipelineSourceIdParameter;
        this.nodePool = nodePoolParameter;
        const steplets = this.getAllSteplets();
        this.isExternal = steplets.some((steplet) => steplet.isExternal());
        this.priority = Math.min(...steplets.map((steplet) => {
            return steplet.getPriority();
        }));
        this.triggeredAt = new Date(Math.min(...steplets.map((steplet) => {
            return new Date(steplet.getTriggeredAt()).getTime();
        })));
    }
    getPriority() {
        return this.priority;
    }
    getTriggeredAt() {
        return this.triggeredAt;
    }
    getProjectId() {
        return this.projectId;
    }
    getPipelineId() {
        return this.pipelineId;
    }
    getPipelineSourceId() {
        return this.pipelineSourceId;
    }
    isApprovalRequired() {
        return this.requiresApproval;
    }
    getApprovalRequestedAt() {
        return this.approvalRequestedAt;
    }
    isWaitingForApproval() {
        return this.waitingForApproval;
    }
    getSteps() {
        return this.steps;
    }
    isExternalStepAffinity() {
        return this.isExternal;
    }
    getNodePool() {
        return this.nodePool;
    }
    isJobStepAffinity() {
        return this.isJobNodePool;
    }
    isSkippable() {
        return this.skipByNoNode || this.skipByNodePoolPermissions || this.skipByNonRootEnforcement;
    }
    isUsingLocalArtifactory() {
        return this.isStepUsingLocalArtifactory;
    }
    getAffinityGroup() {
        return this.affinityGroup;
    }
    getRunId() {
        return this.runId;
    }
    getAllSteplets() {
        let steplets = [];
        this.steps.map((step) => {
            steplets = [...steplets, ...step.getSteplets()];
        });
        return steplets;
    }
}
exports.StepAffinityVo = StepAffinityVo;
//# sourceMappingURL=StepAffinityVo.js.map