"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RunAdjacency_1 = require("../RunAdjacency");
const ApiDataAdapter_1 = require("../../dataAdapter/ApiDataAdapter");
const RunDao_1 = require("../../RunDao");
const StepDao_1 = require("../../StepDao");
describe('RunAdjacency test cases', () => {
    it('should populate when empty triggereableSteps', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyByRunId).toBeDefined();
    });
    it('should populate when there are triggerable steps', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyByRunId).toBeDefined();
    });
    it('should populate when there are triggerable steps and waitOnParentComplete pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 3,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnChildComplete pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 5,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnParentSuccess pipelines', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 4,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([{ id: 1, pipelineId: 1 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
    it('should populate when there are triggerable steps and waitOnParentSuccess pipelines with unsuccesfull parent', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            },
            {
                id: 613,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 4,
                dependentEntityId: 1
            },
            {
                id: 614,
                runId: 1029,
                stepId: 2912,
                stepletId: 2923,
                affinityGroup: 'group',
                dependentEntityType: 0,
                dependentEntityId: 2910
            },
            {
                id: 609,
                runId: 1029,
                stepId: 2910,
                stepletId: 2921,
                affinityGroup: 'group',
                dependentEntityType: -1,
                dependentEntityId: -1
            }
        ]);
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getRuns').mockResolvedValue([]);
        jest
            .spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getPipelines')
            .mockResolvedValue([{ id: 1, latestCompletedRunId: 10, latestSuccessfulRunId: 11 }]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual([]);
    });
});
describe('ChronologicalRun test cases', () => {
    it('should populate when there are triggerable steps with chronological: true enabled at pipelines level', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                isChronologicalRun: true
            }
        ]);
        jest.spyOn(RunDao_1.RunDao.prototype, 'findAll').mockResolvedValueOnce([
            {
                id: 1,
                runNumber: 1,
                pipelineId: 1
            },
            {
                id: 2,
                runNumber: 2,
                pipelineId: 1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual(['1']);
    });
    it('should populate when there are triggerable steps with chronological: true enabled at pipelines level and there are no waitingRuns', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                isChronologicalRun: true
            }
        ]);
        jest.spyOn(RunDao_1.RunDao.prototype, 'findAll').mockResolvedValueOnce([]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual(['1', '2']);
    });
    it('should populate when there are triggerable steps with chronological: true enabled at one pipeline and other pipeline run should start', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 3,
                stepId: 3,
                stepletId: 3,
                runId: 4,
                pipelineId: 3,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                isChronologicalRun: true
            }
        ]);
        jest.spyOn(RunDao_1.RunDao.prototype, 'findAll').mockResolvedValue([
            {
                id: 1,
                runNumber: 1,
                pipelineId: 1
            },
            {
                id: 2,
                runNumber: 2,
                pipelineId: 1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual(['1', '4']);
    });
    it('should populate when there are triggerable steps with chronological: true enabled at one pipeline and only lowest run number step start', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 3,
                stepId: 3,
                stepletId: 3,
                runId: 3,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                isChronologicalRun: true
            }
        ]);
        jest.spyOn(RunDao_1.RunDao.prototype, 'findAll').mockResolvedValue([
            {
                id: 3,
                runNumber: 3,
                pipelineId: 1
            },
            {
                id: 1,
                runNumber: 1,
                pipelineId: 1
            },
            {
                id: 2,
                runNumber: 2,
                pipelineId: 1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyRunIds()).toStrictEqual(['1']);
    });
});
describe('ChronologicalStep test cases', () => {
    it('should populate when there are triggerable steps with chronological: true enabled at step level', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 2,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                chronologicalPipelineStepId: 1,
                isChronologicalStep: true
            },
            {
                id: 3,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 4,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                chronologicalPipelineStepId: 1,
                isChronologicalStep: true
            }
        ]);
        jest.spyOn(StepDao_1.StepDao.prototype, 'findAll').mockResolvedValue([
            {
                id: 1,
                runId: 1,
                pipelineStepId: 1
            },
            {
                id: 2,
                runId: 2,
                pipelineStepId: 1
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyStepIds()).toStrictEqual([1]);
    });
    it('should populate when there are triggerable steps with chronological: true enabled at step level and there are multiple steps in same affinityGroup', async () => {
        jest.spyOn(ApiDataAdapter_1.ApiDataAdapter.prototype, 'getTriggerableSteps').mockResolvedValue([
            {
                id: 1,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 10,
                stepId: 10,
                stepletId: 10,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: 1,
                dependentEntityType: 0
            },
            {
                id: 2,
                stepId: 1,
                stepletId: 1,
                runId: 1,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                chronologicalPipelineStepId: 1,
                isChronologicalStep: true
            },
            {
                id: 3,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1
            },
            {
                id: 4,
                stepId: 2,
                stepletId: 2,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: -1,
                dependentEntityType: -1,
                chronologicalPipelineStepId: 1,
                isChronologicalStep: true
            },
            {
                id: 11,
                stepId: 11,
                stepletId: 11,
                runId: 2,
                pipelineId: 1,
                dependentEntityId: 2,
                dependentEntityType: 0
            }
        ]);
        jest.spyOn(StepDao_1.StepDao.prototype, 'findAll').mockResolvedValue([
            {
                id: 1,
                runId: 1,
                pipelineStepId: 1
            },
            {
                id: 10,
                runId: 1,
                pipelineStepId: 2
            },
            {
                id: 2,
                runId: 2,
                pipelineStepId: 1
            },
            {
                id: 11,
                runId: 2,
                pipelineStepId: 2
            }
        ]);
        const runAdjacency = new RunAdjacency_1.RunAdjacency(new ApiDataAdapter_1.ApiDataAdapter({}));
        await runAdjacency.populate();
        expect(runAdjacency.getRunAdjacencyStepIds()).toStrictEqual([1, 10]);
    });
});
//# sourceMappingURL=RunAdjacency.test.js.map