"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mockGetPipelineSourcesByIdByQuery = jest.fn().mockImplementation((query) => {
    if (query === 'pipelineSourceIds=2') {
        return [];
    }
    else if (query === 'pipelineSourceIds=1') {
        throw new Error('error');
    }
    else {
        return {
            3: { id: 3, environments: ['DEV'] },
            4: { id: 4, environments: ['PROD'] }
        };
    }
});
jest.mock('../../acl', () => {
    return {
        SyncRepository: jest.fn().mockImplementation(() => {
            return {
                getPipelineSourcesByIdByQuery: mockGetPipelineSourcesByIdByQuery
            };
        })
    };
});
const WaitingGroupManager_1 = require("../WaitingGroupManager");
const modules_1 = require("../../modules");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: { config: { apiUrl: 'http://example.com', controlPlaneVersion: '1.23.6', defaultBatchSize: 100 } }
}));
describe('rejectGroup test cases', () => {
    it('should reject group by no node when numberOfNodesNodepool is not a valid number', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 'abcd';
        const nodes = [{ id: 1 }];
        const isEnforceNonRootNodes = true;
        const isInitAsNonRoot = true;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        console.log(result);
        const expectedResult = [{ projectId: 1, skipByNoNode: true }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should reject group by no node when nodes are empty', () => {
        const isOnDemandNodePool = false;
        const numberOfNodesNodepool = 1;
        const nodes = [];
        const isEnforceNonRootNodes = true;
        const isInitAsNonRoot = true;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1, skipByNoNode: true }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should reject group by nonRootEnforcement when isEnforceNonRootNodes is true and isInitAsNonRoot is false', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 1;
        const nodes = [];
        const isEnforceNonRootNodes = true;
        const isInitAsNonRoot = false;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1, skipByNonRootEnforcement: true }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should not reject group by nonRootEnforcement when isEnforceNonRootNodes is false and isInitAsNonRoot is false', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 1;
        const nodes = [];
        const isEnforceNonRootNodes = false;
        const isInitAsNonRoot = false;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1 }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should not reject group by nonRootEnforcement when isEnforceNonRootNodes is false and isInitAsNonRoot is true', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 1;
        const nodes = [];
        const isEnforceNonRootNodes = false;
        const isInitAsNonRoot = true;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1 }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should not reject group by nonRootEnforcement when isEnforceNonRootNodes is true and isInitAsNonRoot is true', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 1;
        const nodes = [{ id: 1 }];
        const isEnforceNonRootNodes = true;
        const isInitAsNonRoot = true;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1 }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('should not reject group by skipByNoNode when isOnDemandNodePool is false and nodes are present', () => {
        const isOnDemandNodePool = false;
        const numberOfNodesNodepool = 1;
        const nodes = [{ id: 1 }];
        const isEnforceNonRootNodes = true;
        const isInitAsNonRoot = true;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1 }];
        expect(result).toStrictEqual(expectedResult);
    });
    it('number of nodepools are 2 and number of steps are 1', () => {
        const isOnDemandNodePool = true;
        const numberOfNodesNodepool = 2;
        const nodes = [{ id: 1 }, { id: 2 }];
        const isEnforceNonRootNodes = false;
        const isInitAsNonRoot = false;
        const waitingGroups = [{ projectId: 1 }];
        const result = WaitingGroupManager_1.WaitingGroupManager.rejectGroup(isOnDemandNodePool, nodes, waitingGroups, isEnforceNonRootNodes, isInitAsNonRoot, numberOfNodesNodepool);
        const expectedResult = [{ projectId: 1 }];
        expect(result).toStrictEqual(expectedResult);
    });
});
describe('setReadyAt test cases', () => {
    it('should update the readyAt value', async () => {
        const SEVEN = 7;
        const spy = jest.spyOn(modules_1.ApiDataAdapter.prototype, 'updateStepsReadyAt').mockResolvedValueOnce(1);
        const waitingGroups = [
            {
                runId: 2,
                affinityGroup: 'first',
                groupStepIds: [
                    {
                        runAdjacencyList: [
                            {
                                id: 14,
                                runId: 2,
                                pipelineId: 1,
                                stepId: 7,
                                stepletId: 7,
                                affinityGroup: 'first',
                                dependentEntityType: -1,
                                dependentEntityId: -1,
                                isChronologicalRun: null,
                                isChronologicalStep: null,
                                chronologicalPipelineStepId: -1
                            }
                        ],
                        requiresApproval: false,
                        stepId: 7,
                        triggeredAt: '2023-09-10T06:29:09.794Z',
                        priority: 9999,
                        readyAt: null,
                        stepletIds: [1],
                        sequence: -1
                    }
                ],
                firstStepsList: ['7']
            }
        ];
        const expctedCaller = [SEVEN];
        const waitingGroupManager = new WaitingGroupManager_1.WaitingGroupManager();
        await waitingGroupManager.setReadyAt(waitingGroups);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledWith(expctedCaller);
        expect(spy).toHaveBeenCalledTimes(1);
    });
    it('should not update if group already has readyAt value', async () => {
        const spy = jest.spyOn(modules_1.ApiDataAdapter.prototype, 'updateStepsReadyAt').mockResolvedValueOnce(1);
        const waitingGroups = [
            {
                runId: 2,
                affinityGroup: 'first',
                groupStepIds: [
                    {
                        runAdjacencyList: [
                            {
                                id: 14,
                                runId: 2,
                                pipelineId: 1,
                                stepId: 7,
                                stepletId: 7,
                                affinityGroup: 'first',
                                dependentEntityType: -1,
                                dependentEntityId: -1,
                                isChronologicalRun: null,
                                isChronologicalStep: null,
                                chronologicalPipelineStepId: -1
                            }
                        ],
                        requiresApproval: false,
                        stepId: 7,
                        triggeredAt: '2023-09-10T06:29:09.794Z',
                        priority: 9999,
                        readyAt: '01-01-2000',
                        stepletIds: [1],
                        sequence: -1
                    }
                ],
                firstStepsList: ['7']
            }
        ];
        const waitingGroupManager = new WaitingGroupManager_1.WaitingGroupManager();
        await waitingGroupManager.setReadyAt(waitingGroups);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(0);
    });
    it('should not update if group already has empty firstStepList value', async () => {
        const spy = jest.spyOn(modules_1.ApiDataAdapter.prototype, 'updateStepsReadyAt').mockResolvedValueOnce(1);
        const waitingGroups = [
            {
                runId: 2,
                affinityGroup: 'first',
                groupStepIds: [
                    {
                        runAdjacencyList: [
                            {
                                id: 14,
                                runId: 2,
                                pipelineId: 1,
                                stepId: 7,
                                stepletId: 7,
                                affinityGroup: 'first',
                                dependentEntityType: -1,
                                dependentEntityId: -1,
                                isChronologicalRun: null,
                                isChronologicalStep: null,
                                chronologicalPipelineStepId: -1
                            }
                        ],
                        requiresApproval: false,
                        stepId: 7,
                        triggeredAt: '2023-09-10T06:29:09.794Z',
                        priority: 9999,
                        readyAt: null,
                        stepletIds: [1],
                        sequence: -1
                    }
                ],
                firstStepsList: []
            }
        ];
        const waitingGroupManager = new WaitingGroupManager_1.WaitingGroupManager();
        await waitingGroupManager.setReadyAt(waitingGroups);
        expect(spy).toBeDefined();
        expect(spy).toHaveBeenCalledTimes(0);
    });
});
describe('skippingByNodePoolPermissionsInAbsenceOfPipelineSource test cases', () => {
    const waitingGroupManager = new WaitingGroupManager_1.WaitingGroupManager();
    const TWO = 2;
    const THREE = 3;
    const FOUR = 4;
    it('should throw error when missingPipelineSourceIds is not empty', async () => {
        const waitingGroup = [{ pipelineSourceId: 1 }];
        const pipelineSourceIds = [TWO];
        const nodePool = { id: 1 };
        await expect(waitingGroupManager.skippingByNodePoolPermissionsInAbsenceOfPipelineSource(pipelineSourceIds, waitingGroup, nodePool)).rejects.toThrow(`PipelineSources cannot be found for the ids: [1]`);
    });
    it('should throw error when syncRepository throws error', async () => {
        const waitingGroup = [{ pipelineSourceId: 1 }];
        const pipelineSourceIds = [1];
        const nodePool = { id: 1 };
        await expect(waitingGroupManager.skippingByNodePoolPermissionsInAbsenceOfPipelineSource(pipelineSourceIds, waitingGroup, nodePool)).rejects.toThrow(`error`);
    });
    it('should update value of skipByNodePoolPermission', async () => {
        const waitingGroup = [{ pipelineSourceId: THREE }, { pipelineSourceId: FOUR }];
        const pipelineSourceIds = [THREE, FOUR];
        const nodePool = { id: 1, environments: ['DEV'] };
        await waitingGroupManager.skippingByNodePoolPermissionsInAbsenceOfPipelineSource(pipelineSourceIds, waitingGroup, nodePool);
        expect(mockGetPipelineSourcesByIdByQuery).toHaveBeenCalledTimes(1);
    });
});
describe('Waiting group filter by approval', () => {
    const waitingGroupManager = new WaitingGroupManager_1.WaitingGroupManager();
    const triggerDate = '05-11-2023';
    jest.spyOn(global, 'Date').mockImplementationOnce(() => triggerDate);
    it('should filter waiting group based on approval', () => {
        const waitingGroups = [
            {
                requiresApproval: true,
                waitingForApproval: true
            },
            {
                requiresApproval: true,
                waitingForApproval: true
            },
            {
                requiresApproval: true,
                approvalRequestedAt: new Date()
            },
            {},
            {
                requiresApproval: true,
                waitingForApproval: false,
                rejectionContext: {}
            }
        ];
        const groupsRequiringApprovalResult = [
            {
                requiresApproval: true,
                waitingForApproval: true
            },
            {
                requiresApproval: true,
                waitingForApproval: true
            },
            {
                requiresApproval: true,
                waitingForApproval: false,
                rejectionContext: {
                    waitingForApproval: {
                        timestamp: expect.any(Date)
                    }
                }
            }
        ];
        const waitingGroupResult = [
            {
                requiresApproval: true,
                approvalRequestedAt: new Date()
            },
            {}
        ];
        const rejectedGroupResult = [
            {
                requiresApproval: true,
                waitingForApproval: false,
                rejectionContext: {
                    waitingForApproval: {
                        timestamp: expect.any(Date)
                    }
                }
            }
        ];
        const result = waitingGroupManager.filterWaitingGroupsByApprovalRequired(waitingGroups);
        expect(result.groupsRequiringApproval).toStrictEqual(groupsRequiringApprovalResult);
        expect(result.waitingGroupsResult).toStrictEqual(waitingGroupResult);
        expect(result.rejectedGroupsWaitingForApproval).toStrictEqual(rejectedGroupResult);
    });
});
//# sourceMappingURL=WaitingGroupManager.test.js.map