"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WaitingStepsByRunAdjacency = void 0;
const node_util_1 = require("node:util");
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
const modules_1 = require("../modules");
class WaitingStepsByRunAdjacency {
    static async getWaitingStepsByRunAdjacencies(waitingGroups) {
        const runAdjacencyBatchSize = 5;
        try {
            const filteredWaitingGroups = [];
            const dataAdapter = modules_1.DataAdapterFactory.getApiDataAdapter();
            await (0, utility_1.eachLimit)(waitingGroups, runAdjacencyBatchSize, async (waitingGroup) => {
                let query = `affinityGroups=${waitingGroup.affinityGroup}&runIds=${waitingGroup.runId}`;
                query += '&include=id';
                try {
                    const runAdjacencies = await dataAdapter.getRunAdjacencyByQuery(query);
                    if (runAdjacencies.length === 0 || runAdjacencies.length !== waitingGroup.runAdjacencyList.length) {
                        this.logger.warn(`Rejecting group with runId:${waitingGroup.runId}, affinityGroup:${waitingGroup.affinityGroup} for inconsistent runAdjacencies`);
                    }
                    else {
                        filteredWaitingGroups.push(waitingGroup);
                    }
                }
                catch (error) {
                    this.logger.warn(`Cannot extract runAdjacency list for the runId: ${waitingGroup.runId}, affinityGroups: ${waitingGroup.affinityGroup} with error: ${(0, node_util_1.inspect)(error)}`);
                }
            });
            return filteredWaitingGroups;
        }
        catch (error) {
            this.logger.warn(`Cannot get waiting steps by runAdjacencies with error: ${error}`);
            throw new Error(error);
        }
    }
}
exports.WaitingStepsByRunAdjacency = WaitingStepsByRunAdjacency;
WaitingStepsByRunAdjacency.logger = logger_1.LoggerFactory.getLogger('WaitingStepsByRunAdjacency');
//# sourceMappingURL=WaitingStepsByRunAdjacency.js.map